==> vue-cli-plugin-swift-1.0.0.tgz: package/index.js <==
const fs = require('fs');
const path = require('path');

function parseMouduleName(name) {
  let index = name.indexOf('-');
  while (index > -1) {
    name = name.split('');
    name.splice(index + 1, 1, name[index + 1].toUpperCase())
    name = name.join('');
    name = name.replace('-', '');
    index = name.indexOf('-');
  }
  return name;
}

/**
 * 读取路由配置，并将路由文件写入入口路由根目录下的 __modules__.ts
 * @param {*} modulesPath 模块根目录
 * @param {*} modules 模块名列表
 * @param {*} entry 入口名称
 */
function generateRouter(modulesPath, modules, entry) {
  let contents = '';
  let routes = [];
  for (let moduleName of modules) {
    if (fs.existsSync(path.resolve(modulesPath, moduleName, 'router.ts'))) {
      let parsedModuleName = parseMouduleName(moduleName);
      contents += `import ${parsedModuleName} from '@/modules/${moduleName}/router';\n`;
      routes.push(parsedModuleName);
    }
  }
  contents += `
declare type Route = {
  root?: boolean;
  path: string;
  children?: Route[];
}
let moduleRouters: Route[] = [${routes.join(', ')}];
let routeMap: {[path: string]: Route} = {};
function mergeRoute (root: Route, children?: Route[]) {
  if (!children) {
    return;
  }
  for (let child of children) {
    root.children = root.children || [];
    let matched = root.children.find(r => r.path === child.path);
    if (matched) {
      mergeRoute(matched, child.children);
    } else {
      root.children.push(child);
    }
  }
}
for (let route of moduleRouters) {
  let routePath = route.path + '-path';
  let rootRouter = routeMap[routePath] || route;
  if (route.root) {
    rootRouter = route;
    delete rootRouter.root;
    route = routeMap[routePath];
  }
  if (route) {
    mergeRoute(rootRouter, route.children);
  }
  routeMap[rootRouter.path + '-path'] = rootRouter;
}
moduleRouters = Object.values(routeMap);
export default moduleRouters;
`;
  fs.writeFileSync(path.resolve(modulesPath, '../', 'entry', entry, 'router', '__modules__.ts'), contents, { encoding: 'utf8' });
}

module.exports = (api, projectOptions) => {
  const rootPath = api.resolve('src');
  const modulesPath = path.resolve(rootPath, 'modules');
  api.registerCommand('swift', args => {
    // 注册 `vue-cli-service swift`
    let moduleConfigPath = path.resolve(modulesPath, 'module.json');
    if (!fs.existsSync(moduleConfigPath)) {
      console.log('请在 src/modules 目录下面生成 module.json 文件！');
      return;
    }
    const modules = require(moduleConfigPath);
    const entries = fs.readdirSync(path.resolve(rootPath, 'entry'));
    for (let entry of entries) {
      if (!modules[entry]) {
        continue;
      }
      generateRouter(modulesPath, modules[entry], entry);
    }
    return true;
  });
  try {
    require('swiftjs');
  } catch(e) {
    console.log('\n\n请手动安装 swiftjs 依赖\n');
    console.log('npm i -S swiftjs --registry http://172.16.1.90:4873\n');
  }
}

==> vue-cli-plugin-swift-1.0.1.tgz: package/index.js <==
const fs = require('fs');
const path = require('path');

function parseMouduleName(name) {
  let index = name.indexOf('-');
  while (index > -1) {
    name = name.split('');
    name.splice(index + 1, 1, name[index + 1].toUpperCase())
    name = name.join('');
    name = name.replace('-', '');
    index = name.indexOf('-');
  }
  return name;
}

/**
 * 读取路由配置，并将路由文件写入入口路由根目录下的 __modules__.ts
 * @param {*} modulesPath 模块根目录
 * @param {*} modules 模块名列表
 * @param {*} entry 入口名称
 */
function generateRouter(modulesPath, modules, entry) {
  let contents = '';
  let routes = [];
  for (let moduleName of modules) {
    if (fs.existsSync(path.resolve(modulesPath, moduleName, 'router.ts'))) {
      let parsedModuleName = parseMouduleName(moduleName);
      contents += `import ${parsedModuleName} from '@/modules/${moduleName}/router';\n`;
      routes.push(parsedModuleName);
    }
  }
  contents += `
declare type Route = {
  root?: boolean;
  path: string;
  children?: Route[];
}
let moduleRouters: Route[] = [${routes.join(', ')}];
let routeMap: {[path: string]: Route} = {};
function mergeRoute (root: Route, children?: Route[]) {
  if (!children) {
    return;
  }
  for (let child of children) {
    root.children = root.children || [];
    let matched = root.children.find(r => r.path === child.path);
    if (matched) {
      mergeRoute(matched, child.children);
    } else {
      root.children.push(child);
    }
  }
}
for (let route of moduleRouters) {
  let routePath = route.path + '-path';
  let rootRouter = routeMap[routePath] || route;
  if (route.root) {
    rootRouter = route;
    delete rootRouter.root;
    route = routeMap[routePath];
  }
  if (route) {
    mergeRoute(rootRouter, route.children);
  }
  routeMap[rootRouter.path + '-path'] = rootRouter;
}
moduleRouters = Object.values(routeMap);
export default moduleRouters;
`;
  fs.writeFileSync(path.resolve(modulesPath, '../', 'entry', entry, 'router', '__modules__.ts'), contents, { encoding: 'utf8' });
}

module.exports = (api, projectOptions) => {
  const rootPath = api.resolve('src');
  const modulesPath = path.resolve(rootPath, 'modules');
  api.registerCommand('swift', args => {
    let modulePath = '';
    if(args.environmental){
      modulePath = `module.${args.environmental}.json`
    }else{
      modulePath = 'module.json'
    }
    // 注册 `vue-cli-service swift`
    let moduleConfigPath = path.resolve(modulesPath, modulePath);
    if (!fs.existsSync(moduleConfigPath)) {
      console.log(`请在 src/modules 目录下面生成 ${modulePath} 文件！`);
      return;
    }
    const modules = require(moduleConfigPath);
    const entries = fs.readdirSync(path.resolve(rootPath, 'entry'));
    for (let entry of entries) {
      if (!modules[entry]) {
        continue;
      }
      generateRouter(modulesPath, modules[entry], entry);
    }
    return true;
  });
  try {
    require('cdjs-swiftjs-plug');
  } catch(e) {
    console.log('\n\n请手动安装 cdjs-swiftjs-plug 依赖\n');
    console.log('npm i -S swiftjs --registry http://172.16.1.90:4873\n');
  }
}
